@@ -161,7 +161,7 @@ class StickProtocol():
 
         # You need to check whether the user is authorized to fetch that SenderKey
         authorized = False
-        exists = True
+        partyExists = True
         if user in member.blocked.all():  # A blocked user is not authorized
             return {'authorized': authorized}
         if isInvitation:  # An invited user is authorized
@@ -179,8 +179,8 @@ class StickProtocol():
             else:
                 party = Party.objects.filter(id=stickId[:36]).first()
                 if not party:
-                    exists = False
-                    return {'exists': exists}
+                    partyExists = False
+                    return {'partyExists': partyExists}
                 # A user connected with another user should be authorized
                 if party.user and (user in party.user.connections.all() or user.phone in party.user.contacts):
                     authorized = True
@@ -216,7 +216,7 @@ class StickProtocol():
             if not PendingKey.objects.filter(user=user, stickId=stickId).exists():
                 PendingKey.objects.create(user=user, owner=member, stickId=stickId)
                 phone = member.phone
-        return {'authorized': authorized, 'senderKey': key, 'phone': phone, 'exists': exists}
+        return {'authorized': authorized, 'senderKey': key, 'phone': phone, 'partyExists': partyExists}
 
     def get_standard_sender_keys(self, data, user, group):
         """
